wechrom
===============================

Python implementation for the WEChroM Model

Documentation
--------------

Documentation and tutorials are hosted in [readthedocs](https://wechrom.readthedocs.io/en/latest/)


Installation
--------------------

To install using pip:

    $ pip install wechrom


To install from the source:

    $ git clone https://github.com/VickyLu001/wechrom.git
    $ pip install -e ./wechrom
    
